pub enum LabelPrepPreference {
SELLERLABEL,
AMAZONLABELONLY,
AMAZONLABELPREFERRED,
}Expand description
LabelPrepPreference : The preference for label preparation for an inbound shipment. The preference for label preparation for an inbound shipment.
Variants
SELLERLABEL
AMAZONLABELONLY
AMAZONLABELPREFERRED